@@ -31,8 +31,8 @@ class If(Constraint):
         """
         Checks one constraint or another depending on the truth value of the condition.
 
-        .. versionchanged:: 0.8.0
-            You can now pass a sequence of parameter names as condition, which
+        .. versionadded:: 0.8.0
+            you can now pass a sequence of parameter names as condition, which
             corresponds to the predicate ``AllSet(*param_names)``.
 
         :param condition:
@@ -73,7 +73,8 @@ class If(Constraint):
         except ConstraintViolated as err:
             desc = (condition.description(ctx) if condition_is_true
                     else condition.negated_description(ctx))
-            raise ConstraintViolated(f"when {desc}, {err}", ctx=ctx)
+            raise ConstraintViolated(
+                f"when {desc}, {err}", ctx=ctx, constraint=self, params=params)
 
     def __repr__(self) -> str:
         if self._else:
